@@ -1,13 +1,13 @@
 /*********************                                                        */
 /*! \file logic_exception.h
  ** \verbatim
- ** Original author: Morgan Deters
- ** Major contributors: none
- ** Minor contributors (to current version): none
+ ** Top contributors (to current version):
+ **   Morgan Deters, Paul Meng, Tim King
  ** This file is part of the CVC4 project.
- ** Copyright (c) 2009-2014  New York University and The University of Iowa
- ** See the file COPYING in the top-level source directory for licensing
- ** information.\endverbatim
+ ** Copyright (c) 2009-2017 by the authors listed in the file AUTHORS
+ ** in the top-level source directory) and their institutional affiliations.
+ ** All rights reserved.  See the file COPYING in the top-level source
+ ** directory for licensing information.\endverbatim
  **
  ** \brief An exception that is thrown when a feature is used outside
  ** the logic that CVC4 is currently using
@@ -22,7 +22,7 @@
 #ifndef __CVC4__SMT__LOGIC_EXCEPTION_H
 #define __CVC4__SMT__LOGIC_EXCEPTION_H
 
-#include <cvc4/util/exception.h>
+#include <cvc4/base/exception.h>
 
 namespace CVC4 {
 
